# ISOSIMpy
ISOSIMpy is an open-source Python package and graphical user interface (GUI) for the analysis of groundwater residence time distributions using lumped parameter models.

::::{grid} 3
:::{grid-item-card}  User Guide
:link: userguide/index
:link-type: doc

User guide on installation, usage, and the basic concepts of ISOSIMpy.
:::
:::{grid-item-card}  Examples
:link: examples/index
:link-type: doc

User guide on installation, usage, and the basic concepts of ISOSIMpy.
:::
:::{grid-item-card}  Code Reference
:link: api/modules
:link-type: doc

ISOSIMpy code reference.
:::
::::

This webpage provides the package documentation, user guides, and examples. The package is hosted on [GitHub](https://github.com/iGW-TU-Dresden/ISOSIMpy), where you can also find the executable that contains the GUI. The package can also be found on [PyPI](https://pypi.org/project/ISOSIMpy/). To install the Python package, simply

`pip install ISOSIMpy`

To use the GUI, the Python package does not need to be installed. You can simply download and use the latest version from [GitHub](https://github.com/iGW-TU-Dresden/ISOSIMpy/releases) (look for the ISOSIMpy-vX.X.X.exe in any release).

```{toctree}
:maxdepth: 2
:caption: Guides
:hidden:

userguide/index
examples/index
```

```{toctree}
:maxdepth: 2
:caption: Code Reference

api/modules
```
